@@ -1,4 +1,3 @@
-import asyncio
 import logging
 from typing import (
     Any,
@@ -17,6 +16,7 @@ from google.protobuf import message
 
 from .api_pb2 import (  # type: ignore
     BinarySensorStateResponse,
+    ButtonCommandRequest,
     CameraImageRequest,
     CameraImageResponse,
     ClimateCommandRequest,
@@ -34,6 +34,7 @@ from .api_pb2 import (  # type: ignore
     LightCommandRequest,
     LightStateResponse,
     ListEntitiesBinarySensorResponse,
+    ListEntitiesButtonResponse,
     ListEntitiesCameraResponse,
     ListEntitiesClimateResponse,
     ListEntitiesCoverResponse,
@@ -45,6 +46,7 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesSelectResponse,
     ListEntitiesSensorResponse,
     ListEntitiesServicesResponse,
+    ListEntitiesSirenResponse,
     ListEntitiesSwitchResponse,
     ListEntitiesTextSensorResponse,
     NumberCommandRequest,
@@ -52,6 +54,8 @@ from .api_pb2 import (  # type: ignore
     SelectCommandRequest,
     SelectStateResponse,
     SensorStateResponse,
+    SirenCommandRequest,
+    SirenStateResponse,
     SubscribeHomeassistantServicesRequest,
     SubscribeHomeAssistantStateResponse,
     SubscribeHomeAssistantStatesRequest,
@@ -69,6 +73,7 @@ from .model import (
     APIVersion,
     BinarySensorInfo,
     BinarySensorState,
+    ButtonInfo,
     CameraInfo,
     CameraState,
     ClimateFanMode,
@@ -97,6 +102,8 @@ from .model import (
     SelectState,
     SensorInfo,
     SensorState,
+    SirenInfo,
+    SirenState,
     SwitchInfo,
     SwitchState,
     TextSensorInfo,
@@ -116,7 +123,6 @@ ExecuteServiceDataType = Dict[
 class APIClient:
     def __init__(
         self,
-        eventloop: asyncio.AbstractEventLoop,
         address: str,
         port: int,
         password: Optional[str],
@@ -124,15 +130,17 @@ class APIClient:
         client_info: str = "aioesphomeapi",
         keepalive: float = 15.0,
         zeroconf_instance: ZeroconfInstanceType = None,
+        noise_psk: Optional[str] = None,
     ):
         self._params = ConnectionParams(
-            eventloop=eventloop,
             address=address,
             port=port,
             password=password,
             client_info=client_info,
             keepalive=keepalive,
             zeroconf_instance=zeroconf_instance,
+            # treat empty psk string as missing (like password)
+            noise_psk=noise_psk or None,
         )
         self._connection: Optional[APIConnection] = None
         self._cached_name: Optional[str] = None
@@ -155,41 +163,33 @@ class APIClient:
         if self._connection is not None:
             raise APIConnectionError(f"Already connected to {self._log_name}!")
 
-        connected = False
-        stopped = False
-
         async def _on_stop() -> None:
-            nonlocal stopped
-
-            if stopped:
-                return
-            stopped = True
+            # Hook into on_stop handler to clear connection when stopped
             self._connection = None
-            if connected and on_stop is not None:
+            if on_stop is not None:
                 await on_stop()
 
         self._connection = APIConnection(self._params, _on_stop)
         self._connection.log_name = self._log_name
 
         try:
-            await self._connection.connect()
-            if login:
-                await self._connection.login()
+            await self._connection.connect(login=login)
         except APIConnectionError:
-            await _on_stop()
+            self._connection = None
             raise
         except Exception as e:
-            await _on_stop()
+            self._connection = None
             raise APIConnectionError(
                 f"Unexpected error while connecting to {self._log_name}: {e}"
             ) from e
 
-        connected = True
-
     async def disconnect(self, force: bool = False) -> None:
         if self._connection is None:
             return
-        await self._connection.stop(force=force)
+        if force:
+            await self._connection.force_disconnect()
+        else:
+            await self._connection.disconnect()
 
     def _check_connected(self) -> None:
         if self._connection is None:
@@ -220,12 +220,14 @@ class APIClient:
         self._check_authenticated()
         response_types: Dict[Any, Optional[Type[EntityInfo]]] = {
             ListEntitiesBinarySensorResponse: BinarySensorInfo,
+            ListEntitiesButtonResponse: ButtonInfo,
             ListEntitiesCoverResponse: CoverInfo,
             ListEntitiesFanResponse: FanInfo,
             ListEntitiesLightResponse: LightInfo,
             ListEntitiesNumberResponse: NumberInfo,
             ListEntitiesSelectResponse: SelectInfo,
             ListEntitiesSensorResponse: SensorInfo,
+            ListEntitiesSirenResponse: SirenInfo,
             ListEntitiesSwitchResponse: SwitchInfo,
             ListEntitiesTextSensorResponse: TextSensorInfo,
             ListEntitiesServicesResponse: None,
@@ -270,6 +272,7 @@ class APIClient:
             NumberStateResponse: NumberState,
             SelectStateResponse: SelectState,
             SensorStateResponse: SensorState,
+            SirenStateResponse: SirenState,
             SwitchStateResponse: SwitchState,
             TextSensorStateResponse: TextSensorState,
             ClimateStateResponse: ClimateState,
@@ -305,6 +308,7 @@ class APIClient:
         self,
         on_log: Callable[[SubscribeLogsResponse], None],
         log_level: Optional[LogLevel] = None,
+        dump_config: Optional[bool] = None,
     ) -> None:
         self._check_authenticated()
 
@@ -315,6 +319,8 @@ class APIClient:
         req = SubscribeLogsRequest()
         if log_level is not None:
             req.level = log_level
+        if dump_config is not None:
+            req.dump_config = dump_config
         assert self._connection is not None
         await self._connection.send_message_callback_response(req, on_msg)
 
@@ -565,6 +571,41 @@ class APIClient:
         assert self._connection is not None
         await self._connection.send_message(req)
 
+    async def siren_command(
+        self,
+        key: int,
+        state: Optional[bool] = None,
+        tone: Optional[str] = None,
+        volume: Optional[float] = None,
+        duration: Optional[int] = None,
+    ) -> None:
+        self._check_authenticated()
+
+        req = SirenCommandRequest()
+        req.key = key
+        if state is not None:
+            req.state = state
+            req.has_state = True
+        if tone is not None:
+            req.tone = tone
+            req.has_tone = True
+        if volume is not None:
+            req.volume = volume
+            req.has_volume = True
+        if duration is not None:
+            req.duration = duration
+            req.has_duration = True
+        assert self._connection is not None
+        await self._connection.send_message(req)
+
+    async def button_command(self, key: int) -> None:
+        self._check_authenticated()
+
+        req = ButtonCommandRequest()
+        req.key = key
+        assert self._connection is not None
+        await self._connection.send_message(req)
+
     async def execute_service(
         self, service: UserService, data: ExecuteServiceDataType
     ) -> None:
