@@ -1,5 +1,6 @@
 from .api_pb2 import (  # type: ignore
     BinarySensorStateResponse,
+    ButtonCommandRequest,
     CameraImageRequest,
     CameraImageResponse,
     ClimateCommandRequest,
@@ -24,6 +25,7 @@ from .api_pb2 import (  # type: ignore
     LightCommandRequest,
     LightStateResponse,
     ListEntitiesBinarySensorResponse,
+    ListEntitiesButtonResponse,
     ListEntitiesCameraResponse,
     ListEntitiesClimateResponse,
     ListEntitiesCoverResponse,
@@ -35,6 +37,7 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesSelectResponse,
     ListEntitiesSensorResponse,
     ListEntitiesServicesResponse,
+    ListEntitiesSirenResponse,
     ListEntitiesSwitchResponse,
     ListEntitiesTextSensorResponse,
     NumberCommandRequest,
@@ -44,6 +47,8 @@ from .api_pb2 import (  # type: ignore
     SelectCommandRequest,
     SelectStateResponse,
     SensorStateResponse,
+    SirenCommandRequest,
+    SirenStateResponse,
     SubscribeHomeassistantServicesRequest,
     SubscribeHomeAssistantStateResponse,
     SubscribeHomeAssistantStatesRequest,
@@ -60,6 +65,50 @@ class APIConnectionError(Exception):
     pass
 
 
+class InvalidAuthAPIError(APIConnectionError):
+    pass
+
+
+class ResolveAPIError(APIConnectionError):
+    pass
+
+
+class ProtocolAPIError(APIConnectionError):
+    pass
+
+
+class RequiresEncryptionAPIError(ProtocolAPIError):
+    pass
+
+
+class SocketAPIError(APIConnectionError):
+    pass
+
+
+class SocketClosedAPIError(SocketAPIError):
+    pass
+
+
+class HandshakeAPIError(APIConnectionError):
+    pass
+
+
+class InvalidEncryptionKeyAPIError(HandshakeAPIError):
+    pass
+
+
+class PingFailedAPIError(APIConnectionError):
+    pass
+
+
+class TimeoutAPIError(APIConnectionError):
+    pass
+
+
+class ReadFailedAPIError(APIConnectionError):
+    pass
+
+
 MESSAGE_TYPE_TO_PROTO = {
     1: HelloRequest,
     2: HelloResponse,
@@ -115,4 +164,9 @@ MESSAGE_TYPE_TO_PROTO = {
     52: ListEntitiesSelectResponse,
     53: SelectStateResponse,
     54: SelectCommandRequest,
+    55: ListEntitiesSirenResponse,
+    56: SirenStateResponse,
+    57: SirenCommandRequest,
+    61: ListEntitiesButtonResponse,
+    62: ButtonCommandRequest,
 }
