@@ -104,6 +104,13 @@ class DeviceInfo(APIModelBase):
     esphome_version: str = ""
     project_name: str = ""
     project_version: str = ""
+    webserver_port: int = 0
+
+
+class EntityCategory(APIIntEnum):
+    NONE = 0
+    CONFIG = 1
+    DIAGNOSTIC = 2
 
 
 @dataclass(frozen=True)
@@ -113,6 +120,10 @@ class EntityInfo(APIModelBase):
     name: str = ""
     unique_id: str = ""
     disabled_by_default: bool = False
+    icon: str = ""
+    entity_category: Optional[EntityCategory] = converter_field(
+        default=EntityCategory.NONE, converter=EntityCategory.convert
+    )
 
 
 @dataclass(frozen=True)
@@ -164,8 +175,12 @@ class CoverState(EntityState):
     legacy_state: Optional[LegacyCoverState] = converter_field(
         default=LegacyCoverState.OPEN, converter=LegacyCoverState.convert
     )
-    position: float = 0.0
-    tilt: float = 0.0
+    position: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    tilt: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
     current_operation: Optional[CoverOperation] = converter_field(
         default=CoverOperation.IDLE, converter=CoverOperation.convert
     )
@@ -224,8 +239,12 @@ class LightInfo(EntityInfo):
     supported_color_modes: List[int] = converter_field(
         default_factory=list, converter=list
     )
-    min_mireds: float = 0.0
-    max_mireds: float = 0.0
+    min_mireds: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    max_mireds: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
     effects: List[str] = converter_field(default_factory=list, converter=list)
 
     # deprecated, do not use
@@ -288,16 +307,34 @@ class LightInfo(EntityInfo):
 @dataclass(frozen=True)
 class LightState(EntityState):
     state: bool = False
-    brightness: float = 0.0
+    brightness: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
     color_mode: int = 0
-    color_brightness: float = 0.0
-    red: float = 0.0
-    green: float = 0.0
-    blue: float = 0.0
-    white: float = 0.0
-    color_temperature: float = 0.0
-    cold_white: float = 0.0
-    warm_white: float = 0.0
+    color_brightness: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    red: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    green: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    blue: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    white: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    color_temperature: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    cold_white: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    warm_white: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
     effect: str = ""
 
 
@@ -316,7 +353,6 @@ class LastResetType(APIIntEnum):
 
 @dataclass(frozen=True)
 class SensorInfo(EntityInfo):
-    icon: str = ""
     device_class: str = ""
     unit_of_measurement: str = ""
     accuracy_decimals: int = 0
@@ -338,7 +374,6 @@ class SensorState(EntityState):
 # ==================== SWITCH ====================
 @dataclass(frozen=True)
 class SwitchInfo(EntityInfo):
-    icon: str = ""
     assumed_state: bool = False
 
 
@@ -350,7 +385,7 @@ class SwitchState(EntityState):
 # ==================== TEXT SENSOR ====================
 @dataclass(frozen=True)
 class TextSensorInfo(EntityInfo):
-    icon: str = ""
+    pass
 
 
 @dataclass(frozen=True)
@@ -506,12 +541,16 @@ class ClimateState(EntityState):
 # ==================== NUMBER ====================
 @dataclass(frozen=True)
 class NumberInfo(EntityInfo):
-    icon: str = ""
-    min_value: float = 0.0
-    max_value: float = 0.0
+    min_value: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
+    max_value: float = converter_field(
+        default=0.0, converter=fix_float_single_double_conversion
+    )
     step: float = converter_field(
         default=0.0, converter=fix_float_single_double_conversion
     )
+    unit_of_measurement: str = ""
 
 
 @dataclass(frozen=True)
@@ -525,7 +564,6 @@ class NumberState(EntityState):
 # ==================== SELECT ====================
 @dataclass(frozen=True)
 class SelectInfo(EntityInfo):
-    icon: str = ""
     options: List[str] = converter_field(default_factory=list, converter=list)
 
 
@@ -535,6 +573,27 @@ class SelectState(EntityState):
     missing_state: bool = False
 
 
+# ==================== SIREN ====================
+@dataclass(frozen=True)
+class SirenInfo(EntityInfo):
+    tones: List[str] = converter_field(default_factory=list, converter=list)
+    supports_volume: bool = False
+    supports_duration: bool = False
+
+
+@dataclass(frozen=True)
+class SirenState(EntityState):
+    state: bool = False
+
+
+# ==================== BUTTON ====================
+@dataclass(frozen=True)
+class ButtonInfo(EntityInfo):
+    device_class: str = ""
+
+
+# ==================== INFO MAP ====================
+
 COMPONENT_TYPE_TO_INFO: Dict[str, Type[EntityInfo]] = {
     "binary_sensor": BinarySensorInfo,
     "cover": CoverInfo,
@@ -547,6 +606,8 @@ COMPONENT_TYPE_TO_INFO: Dict[str, Type[EntityInfo]] = {
     "climate": ClimateInfo,
     "number": NumberInfo,
     "select": SelectInfo,
+    "siren": SirenInfo,
+    "button": ButtonInfo,
 }
 
 
